/*!
 **************************************************************************
 * \file defines.h
 *
 * \brief
 *    Header file containing some useful global definitions
 *
 * \author
 *    Main contributors (see contributors.h for copyright, address and affiliation details)
 *     - Detlev Marpe
 *     - Karsten Shring                 <suehring@hhi.de> 
 *     - Alexis Michael Tourapis         <alexismt@ieee.org> 
 *   
 *
 * \date
 *    21. March 2001
 **************************************************************************
 */


#ifndef _DEFINES_H_
#define _DEFINES_H_

#define NOKIA_USTC_3DV            1

#if defined _DEBUG
# define TRACE                    1      //!< 0:Trace off 1:Trace on 2:detailed CABAC context information
#else
# define TRACE                    0    //!< 0:Trace off 1:Trace on 2:detailed CABAC context information
#endif

#if NOKIA_USTC_3DV
#define JM                  "17 (FRExt)"
#define VERSION             "8.0" // Result of 4nd JCT-3V meeting. (May.2013)
//////////////////////////////////////////
#define GVD_E0105 0            // JCT3V-E0105 is HP mode only. Please set value 1 and Re-Compile.
//////////////////////////////////////////
#if GVD_E0105 // JCT3V-E0105 = HP mode.
#define LOW_PROFILE                           0     //!< 0:HP 1:EHP
#else
#define LOW_PROFILE                           1     //!< 0:HP 1:EHP
#endif
#if LOW_PROFILE
#define EXT_VERSION         "LOW Profile"
#else
#define EXT_VERSION         "HIGH  Profile"
#endif

#else
#define JM                  "17 (FRExt)"
#define VERSION             "17.2"
#define EXT_VERSION         "(FRExt)"
#endif

#define GET_METIME                1    //!< Enables or disables ME computation time
#define DUMP_DPB                  0    //!< Dump DPB info for debug purposes
#define PRINTREFLIST              0    //!< Print ref list info for debug purposes
#define IMGTYPE                   0   //!< Define imgpel size type. 0 implies byte (cannot handle >8 bit depths) and 1 implies unsigned short
#define ENABLE_FIELD_CTX          1    //!< Enables field context types for CABAC. If disabled, results in speedup for progressive content.
#define ENABLE_HIGH444_CTX        1    //!< Enables High 444 context types for CABAC. If disabled, results in speedup of non High444 profile encodings.
#define DEBUG_BITDEPTH            0    //!< Ensures that > 8 bit content have no values that would result in out of range results
#define ALLOW_GRAYSCALE           1    //!< Allow encoding in grayscale
#define ZEROSNR                   0    //!< PSNR computation method
#define USE_RND_COST              0    //!< Perform ME RD decision using a rounding estimate of the motion cost
#define JM_INT_DIVIDE             1
#define JM_MEM_DISTORTION         0
#define JCOST_CALC_SCALEUP        1    //!< 1: J = (D<<LAMBDA_ACCURACY_BITS)+Lambda*R; 0: J = D + ((Lambda*R+Rounding)>>LAMBDA_ACCURACY_BITS)
#define INTRA_RDCOSTCALC_ET       1    //!< Early termination 
#define INTRA_RDCOSTCALC_NNZ      1    //1: to recover block's nzn after rdcost calculation;
#define JCOST_OVERFLOWCHECK       0    //!<1: to check the J cost if it is overflow>
#define JM_PARALLEL_DEBLOCK       0    //!< Enables Parallel Deblocking


#define EOS_OUTPUT                0 



#if NOKIA_USTC_3DV

//>>>tools belong to  HP & EHP
#define MAX_DISPLAYS              32
#define MVC_EXTENSION_ENABLE      0      //!< enable support for the Multiview High Profile
#define MAX_CODEVIEW              16     //!<the max number of coding view
#define MAX_CODEVIEWPLUSDEPTH     32     //!<the max number of coding view plus depth
#define MAX_VIEWREFERENCE          2

#define DEBUG_MVC_PRED_STRUCT      0
#define DEBUG_MMCO                 0
#define DEBUG_RPLR                 0
#define REDUCED_RES                1
#define LANCZOS3                   0
#define BI_LINEAR                  1

#define IMG_Y                      0
#define IMG_U                      1
#define IMG_V                      2
#define NOKIA_HLS_ADOPTION_M24892  1

#if GVD_E0105 // JCT3V-E0105 = HP mode.
#define DEPTH_PARAMETER_SET         0   // JCT2-A0008
#define NOKIA_DISP_CALC_B0150       0   // JCT3V-B0150
#define SONY_MDFY_SEI_AQINF_M24730  1     // EHP / HP both use.
#else
#define DEPTH_PARAMETER_SET         1     // JCT2-A0008
#define NOKIA_DISP_CALC_B0150       1   // JCT3V-B0150
#endif
#define NOKIA_UPMVD_B0147           1   // JCT3V-B0147
#define NOKIA_DEPTH_SEI_C0162       1   // JCT3V-C0162
#define REF_DISP_SEI_A0163          1   // JCT3V-A0163
#define ITRI_INTERLACE              1 // ITRI Interlace tool
#define ITRI_POST_PROCESS_E0137     1    // JCT3V-E0137
//<<< tools belong to  HP & EHP

#if LOW_PROFILE
//>>>tools belong to  EHP
#define QC_NBDV_E0136                          1
#define MTK_SKIP_DIRECT_A0045                  1      //  JCT2-A0045
#define JOINT_VIEW_FILTER                      1      
#define DRWP                                   1      //!<depth range based weight prediction
#define VISBD_VSP                              1         
#define DEPTH_BASED_MVP                        1         
#define GRADUAL_VIEW_REFRESH                   1         
#define ADAPTIVE_MMCO_REORDER                  1         
#define MAX_TEMPORAL_LEVELS                    6         
#define SLICE_HEADER_PREDICTION                1      //!<Slice header prediction from texture to depth, or depth to texture
#define IVMP                                   0      //!<Inside View Motion Prediction from texture to depth
#define SONY_MDFY_SEI_AQINF_M24730             1      //!<depth_acquisition_info SEI m24730
#define NTT_MDFY_SEI_DAQINF_A0140              1      //!<depth_acquisition_info SEI modification based on JCT2-A0140
#define POZNAN_NONLINEAR_DEPTH                 1      //!<Non-linear depth representation
#define POZNAN_NTT_DEPTH_REPRESENTATION_SEI    1      //!<Depth Representation SEI
#define SAIT_DEPTH_INTRA_PREDICTION            0
#define SAIT_RDO_M23662                        1
#define SAIT_POST_DILATION_A0038               1      //!<depth dilation in post processing
#define SMRC_ALC_M26683                        1      //!< enables using ALC tools
#define SMRC_SAIT_RUN_LENGTH_SKIP_D0115        1
#define QC_GVSP_B0054                          0
#define DRWP                                   1      //!<depth range based weight prediction
#define BVSP_BLOCK                         1  // 0 - original BVSP(bugy with depth1.0), 1 - 1x1 (2x2 with depth 0.5), 2 - 2x2 (4x4 with depth0.5)
#define MTK_SKIP_DIRECT_REFIDX_CHECK_F0114     1     //bug-fix for the disparity-based Skip and Direct modes based on JCT3V-F0114
//<<< tools belong to  EHP
#endif

#if BVSP_BLOCK
#define BLOCK_VSP_T                            8  //1 - 1x1, 2 - 2x2, 4  4x4    //change to 4x4 based on JCT3V-C0130
#endif

#define BVSP_DV_TF_FIX                         1
#define BVSP_DV_DF_FIX                         1
#if BVSP_DV_DF_FIX
#define DMVP_GET_MVP_MODIFY                    1
#endif

#if POZNAN_NONLINEAR_DEPTH
#define SAIT_INDR_C0094                        1      // JCT3V-C0094: Improved Nonlinear Depth Representation
#endif

#if SMRC_SAIT_RUN_LENGTH_SKIP_D0115
#define SMRC_SKIP_SERIES_MAX_LEN               16
#endif

#if SMRC_ALC_M26683
#define QC_ALC_SIMP_C0054                      1      // JCT3V-C0054
#define SAIT_ALC_SIMP_D0116                    1

#define USE_MR_METRIC_FOR_ALC     1 //!< enables using Mean-removed metric for ALC inter-view prediction
#define MR_METRIC_WITH_DC_ADD     1 //!< enables addition of sum of abs differences of DC to MR_SAD4x4
#define FULL_SEARCH_FOR_ALC       1 //!< enables using Full Search for displacement vector estimation
#define SMRC_CHECK_ALC_SKIP_BEFORE_STANDARD_MODES 1 //!< enables checking of ALC skip mode before common skip mode
#define NUM_MB_ALC_CTX            3
#endif

#if JOINT_VIEW_FILTER
#define PRE_JVF                      1
#define INLOOP_JVF                   1
#define MAX_SIZE_REPORT              1024
#else
#define PRE_JVF                      0
#define INLOOP_JVF                   0
#endif

#if SAIT_RDO_M23662
#define max(a,b)                     (((a) > (b)) ? (a) : (b))
#define min(a,b)                     (((a) < (b)) ? (a) : (b))
#define SAIT_RDO_M24826              1

#if SAIT_RDO_M24826
#define MAX_SYN_VIEWS                64
#define MAX_VIEWS                    64
#endif
#endif

#if SAIT_DEPTH_INTRA_PREDICTION
#define SAIT_DISP                     1
#define SAIT_PSIP                     1
#if SAIT_DISP
#define ETRIKHU_DEBLOCK_IN_DISP       1
#endif
#endif

#if DEPTH_BASED_MVP
#define D_MVP_MODE                    1 //!<0: complex mode, 1:fast mode
#define SAIT_INTER_VIEW_MVP_M24824    1 //!< 1: Enable improved inter-view motion vector prediction. 0: Disable. - Jin Young Lee (Samsung&Sharp)
#define SAIT_DISP_BASED_SAD_M24824    1 //!< 1: Enable disparity-based SAD for skip/direct motion vector competitioin. 0: Disable. - Jin Young Lee
#define SAIT_SKIP_MVP_COMMENT_M24824  1 //!< Editor's comment >> 1: Average disparity for skip inter-view MV. 0: Max disaprity for skip inter-view MV.
#define SAIT_SHIFT_SAD_COMMENT_M24824 1 //!< Editor's comment >> 1: Multiplication for disparity SAD. 0: Shift operation for disparity SAD.
#define SAIT_MTK_MAX_DV_SIMP_B0149_B0081  1 // JCT3V-B0149(Samsung)&JCT3V-B0081(MTK)
#define SAIT_SKIP_DIRECT_MVP_B0151    1 // JCT3V-B0151 
#define SAIT_TEMPORAL_MVP_B0153       1 // JCT3V-B0153
#define MTK_UNIDV_INTERVIEW_MVP_C0133 1 //JCT3V-C0133
#define MTK_REFIDX_DERIVATION_C0140   1 //JCT3V-C0140
#define MTK_SAIT_MB_LEVEL_MAX_DV_D0107    1  //JCT3V-D0107 MB-level Max DV derivation
#if SAIT_INTER_VIEW_MVP_M24824 && !MTK_SAIT_MB_LEVEL_MAX_DV_D0107
#define MTK_MAX_DV_SIMP_A0046         1 // JCT2-A0046 
#endif
#define MTK_DEPTH_ONLY_DV_CONVERSION  1  //JCT3V-E0164
#endif

#if VISBD_VSP
#define NOKIA_USTC_B_VSP_M26069       1
#define NOKIA_HLS_ADOPTION_M24890     1
#if !QC_GVSP_B0054
#define MERL_VSP                      1 //!< 1: Enable adaptive reference for SKIP/DIRECT mode. 0: Disable. -Dong
#if MERL_VSP
#define DEBUG_MERL_VSP                0
#endif
#if MERL_VSP || NOKIA_USTC_B_VSP_M26069
#define SAIT_CASFP_M24819             1 //!< 1: Enable context-based adaptive skip flag positioning (CASFP) for view synthesis skip mode. 0: Disable. - Jin Young Lee
#endif
#endif
#if REDUCED_RES
#define QC_VSP_Asymmetric_Resolution  1
#endif
#endif

#if SLICE_HEADER_PREDICTION
#define  FLEXIBLE_PRED_M24946_M24981  1
#endif

#if DRWP
#define NOKIA_USTC_INT_DRWP_M26074    1
#endif

#if GVD_E0105 // JCT3V-E0105 = HP mode.
#define NOKIA_USTC_IVP_VSP_D0126         0
#else
#define NOKIA_USTC_IVP_VSP_D0126         1
#endif

/*    Bug fixes   */
#define SAIT_PSIP_CAVLC_BUGFIX_V5     1 // 1. moving cavlc function (macroblock.x->vlc.x)
#define SAIT_RDO_BUGFIX_V5            1 // 2. support full resolution for VSO (#define REDUCED_RES 0)
#define SAIT_SEI_BUGFIX_V5            1 // 3. support full resolution for SEI (#define REDUCED_RES 0)
#define BUG_FIXED_v6_1                1 //!Full res depth coding, memorry allocation in ALC, DEPTH_PARAM
#define SMRC_BUGFIXES_Oct2012         1
#define BUG_FIXED_C0071               1
#define SAIT_TEMPORAL_MVP_BUGFIX_V7   1 // JCT3V-B0153

// JCT3V-G0239
#define ALC_IPP_BUGFIX                1
#define DMVP_VSP_DECOUPLING_BUGFIX    1
#define VSP_SYNTAX_BUGFIX             1
#define BUGFIX_BSLICE_IVP_VSP			1 
#endif

#define DEBUG_MEM_LEAK                0 //!<detect probable memory leak for window platform

#if DEBUG_MEM_LEAK
#define _CRTDBG_MAP_ALLOC
#include <stdlib.h>
#include <crtdbg.h>
#endif



#define MVC_DEVELOPPING           1  

#define EPZSREF                   1

#define MAX_RC_MODE               3
#define RC_MAX_TEMPORAL_LEVELS    5

#define SSE_MEMORY_ALIGNMENT      16

//#define BEST_NZ_COEFF 1   // yuwen 2005.11.03 => for high complexity mode decision (CAVLC, #TotalCoeff)


//landeyan
#define FORCE_YUV400              1
#define FORCE400_OUTPUT420        1
//landeyan


//AVC Profile IDC definitions
enum {
  FREXT_CAVLC444 = 44,       //!< YUV 4:4:4/14 "CAVLC 4:4:4"
  BASELINE       = 66,       //!< YUV 4:2:0/8  "Baseline"
  MAIN           = 77,       //!< YUV 4:2:0/8  "Main"
  EXTENDED       = 88,       //!< YUV 4:2:0/8  "Extended"
  FREXT_HP       = 100,      //!< YUV 4:2:0/8  "High"
  FREXT_Hi10P    = 110,      //!< YUV 4:2:0/10 "High 10"
  FREXT_Hi422    = 122,      //!< YUV 4:2:2/10 "High 4:2:2"
  FREXT_Hi444    = 244,      //!< YUV 4:4:4/14 "High 4:4:4"
  MULTIVIEW_HIGH = 118,      //!< YUV 4:2:0/8  "Multiview High"
  STEREO_HIGH    = 128,       //!< YUV 4:2:0/8  "Stereo High"
#if NOKIA_USTC_3DV
  ThreeDV_HIGH   = 138,
  ThreeDV_EXTEND_HIGH = 139
#endif
} ProfileIDC;

// Some typedefs used in the software
#include "types.h"

#define FILE_NAME_SIZE  255
#define INPUT_TEXT_SIZE 1024

#define CAVLC_LEVEL_LIMIT 2063

#if (ENABLE_HIGH444_CTX == 1)
# define NUM_BLOCK_TYPES 22  
#else
# define NUM_BLOCK_TYPES 10
#endif

///#define _LEAKYBUCKET_

// ---------------------------------------------------------------------------------
// FLAGS and DEFINES for new chroma intra prediction, Dzung Hoang
// Threshold values to zero out quantized transform coefficients.
// Recommend that _CHROMA_COEFF_COST_ be low to improve chroma quality
#define _LUMA_COEFF_COST_       4 //!< threshold for luma coeffs
#define _CHROMA_COEFF_COST_     4 //!< threshold for chroma coeffs, used to be 7
#define _LUMA_MB_COEFF_COST_    5 //!< threshold for luma coeffs of inter Macroblocks
#define _LUMA_8x8_COEFF_COST_   5 //!< threshold for luma coeffs of 8x8 Inter Partition

//#define IMG_PAD_SIZE           20 //!< Number of pixels padded around the reference frame (>=4)
//#define IMG_PAD_SIZE_TIMES4    80 //!< Number of pixels padded around the reference frame in subpel units(>=16)
#define IMG_PAD_SIZE_X         32 //!< Number of pixels padded around the reference frame (>=4)
#define IMG_PAD_SIZE_Y         18  //!< Number of pixels padded around the reference frame (>=4)
#define IMG_PAD_SIZE_X_TIMES4  128 //!< Number of pixels padded around the reference frame in subpel units(>=16)
#define IMG_PAD_SIZE_Y_TIMES4  72 //!< Number of pixels padded around the reference frame in subpel units(>=16)

#define MAX_VALUE       999999   //!< used for start value for some variables
#define INVALIDINDEX  (-135792468)

#define DUMMY   14
#define ET_SIZE 300      //!< size of error text buffer

#define  LAMBDA_ACCURACY_BITS         5
#define  LAMBDA_FACTOR(lambda)        ((int)((double)(1 << LAMBDA_ACCURACY_BITS) * lambda + 0.5))

#if (IMGTYPE == 0)
#define DISTBLK_MAX  INT_MAX
#elif (IMGTYPE == 2)
#define DISTBLK_MAX  FLT_MAX
#else
#define DISTBLK_MAX  ((distblk) INT_MAX << LAMBDA_ACCURACY_BITS)
#endif

#define  MAXSLICEPERPICTURE           100
#define  MAX_REFERENCE_PICTURES        32

#define BLOCK_SHIFT            2
#define BLOCK_SIZE             4
#define BLOCK_SIZE_8x8         8
#define SMB_BLOCK_SIZE         8
#define BLOCK_PIXELS          16
#define MB_BLOCK_SIZE         16
#define MB_PIXELS            256 // MB_BLOCK_SIZE * MB_BLOCK_SIZE
#define MB_PIXELS_SHIFT        8 // log2(MB_BLOCK_SIZE * MB_BLOCK_SIZE)
#define MB_BLOCK_SHIFT         4
#define BLOCK_MULTIPLE         4 // (MB_BLOCK_SIZE/BLOCK_SIZE)
#define MB_BLOCK_PARTITIONS   16 // (BLOCK_MULTIPLE * BLOCK_MULTIPLE)
#define BLOCK_CONTEXT         64 // (4 * MB_BLOCK_PARTITIONS)
// These variables relate to the subpel accuracy supported by the software (1/4)
#define BLOCK_SIZE_SP      16  // BLOCK_SIZE << 2
#define BLOCK_SIZE_8x8_SP  32  // BLOCK_SIZE8x8 << 2

// wavelet based weighted PSNR wavelet levels
#define NUM_WAVELET_LEVEL 4

// RDOQ
#define MAX_PREC_COEFF    25



//  Available MB modes
enum {
  PSKIP        =  0,
  BSKIP_DIRECT =  0,
  P16x16       =  1,
  P16x8        =  2,
  P8x16        =  3,
  SMB8x8       =  4,
  SMB8x4       =  5,
  SMB4x8       =  6,
  SMB4x4       =  7,
  P8x8         =  8,
  I4MB         =  9,
  I16MB        = 10,
  IBLOCK       = 11,
  SI4MB        = 12,
  I8MB         = 13,
  IPCM         = 14,
#if QC_GVSP_B0054
  PVSP_SKIP    = 15,
  BVSP_DIRECT  = 15,
  P16x16_VSP   = 16,
  
  P16x8_UP_VSP = 17,
  P16x8_DN_VSP = 18,
  P8x16_LT_VSP = 19,
  P8x16_RT_VSP = 20,
  
  P8x8_UPLT_VSP = 21,
  P8x8_UPRT_VSP = 22,
  P8x8_DNLT_VSP = 23,
  P8x8_DNRT_VSP = 24,

  P8x8_UPLT_NVSP = 25,
  P8x8_UPRT_NVSP = 26,
  P8x8_DNLT_NVSP = 27,
  P8x8_DNRT_NVSP = 28,

  P8x8_LT_DIAG_VSP = 29,
  P8x8_RT_DIAG_VSP = 30,
  P8x8_UP_VSP = 31,
  P8x8_DN_VSP = 32,
  P8x8_LT_VSP = 33,
  P8x8_RT_VSP = 34,
#if SAIT_DISP
  DISPMODE     = 35,
  MAXMODE      = 36
#else
  MAXMODE      = 35
#endif
#else
#if MERL_VSP
  PVSP_SKIP    = 15,
  BVSP_DIRECT  = 15,
#if SAIT_DISP
  DISPMODE     = 16,
  MAXMODE      = 17
#else
  MAXMODE      = 16
#endif
#else
#if SAIT_DISP
  DISPMODE     = 15,
  MAXMODE      = 16
#else
  MAXMODE      = 15
#endif
#endif
#endif
} MBModeTypes;

// number of intra prediction modes
#define NO_INTRA_PMODE  9

// Direct Mode types
enum {
  DIR_TEMPORAL = 0, //!< Temporal Direct Mode
  DIR_SPATIAL  = 1 //!< Spatial Direct Mode
} DirectModes;

// CAVLC block types
enum {
  LUMA              =  0,
  LUMA_INTRA16x16DC =  1,
  LUMA_INTRA16x16AC =  2,
  CB                =  3,
  CB_INTRA16x16DC   =  4,
  CB_INTRA16x16AC   =  5,
  CR                =  8,
  CR_INTRA16x16DC   =  9,
  CR_INTRA16x16AC   = 10
} CAVLCBlockTypes;

// CABAC block types
enum {
  LUMA_16DC     =   0,
  LUMA_16AC     =   1,
  LUMA_8x8      =   2,
  LUMA_8x4      =   3,
  LUMA_4x8      =   4,
  LUMA_4x4      =   5,
  CHROMA_DC     =   6,
  CHROMA_AC     =   7,
  CHROMA_DC_2x4 =   8,
  CHROMA_DC_4x4 =   9,
  CB_16DC       =  10,
  CB_16AC       =  11,
  CB_8x8        =  12,
  CB_8x4        =  13,
  CB_4x8        =  14,
  CB_4x4        =  15,
  CR_16DC       =  16,
  CR_16AC       =  17,
  CR_8x8        =  18,
  CR_8x4        =  19,
  CR_4x8        =  20,
  CR_4x4        =  21
} CABACBlockTypes;

#if SAIT_DISP
#define IS_INTRA(MB)    ((MB)->mb_type==SI4MB || (MB)->mb_type==I4MB || (MB)->mb_type==I16MB || (MB)->mb_type==I8MB || (MB)->mb_type==IPCM || (MB)->mb_type==DISPMODE)
#else
#define IS_INTRA(MB)    ((MB)->mb_type==SI4MB || (MB)->mb_type==I4MB || (MB)->mb_type==I16MB || (MB)->mb_type==I8MB || (MB)->mb_type==IPCM)
#endif

#define LEVEL_NUM         6
#define TOTRUN_NUM       15
#define RUNBEFORE_NUM     7
#define RUNBEFORE_NUM_M1  6

// Quantization parameter range
#define MIN_QP          0
#define MAX_QP          51
#define SHIFT_QP        12

// 4x4 intra prediction modes 
enum {
  VERT_PRED            = 0,
  HOR_PRED             = 1,
  DC_PRED              = 2,
  DIAG_DOWN_LEFT_PRED  = 3,
  DIAG_DOWN_RIGHT_PRED = 4,
  VERT_RIGHT_PRED      = 5,
  HOR_DOWN_PRED        = 6,
  VERT_LEFT_PRED       = 7,
  HOR_UP_PRED          = 8
} I4x4PredModes;

// 16x16 intra prediction modes
enum {
  VERT_PRED_16   = 0,
  HOR_PRED_16    = 1,
  DC_PRED_16     = 2,
  PLANE_16       = 3
} I16x16PredModes;

// 8x8 chroma intra prediction modes
enum {
  DC_PRED_8     =  0,
  HOR_PRED_8    =  1,
  VERT_PRED_8   =  2,
  PLANE_8       =  3
} I8x8PredModes;

#define INIT_FRAME_RATE 30
enum {
  EOS = 1,    //!< End Of Sequence
  SOP = 2,    //!< Start Of Picture
  SOS = 3     //!< Start Of Slice
};

// MV Prediction types
enum {
  MVPRED_MEDIAN   = 0,
  MVPRED_L        = 1,
  MVPRED_U        = 2,
  MVPRED_UR       = 3
} MVPredTypes;

#define MAX_SYMBOLS_PER_MB  1200  //!< Maximum number of different syntax elements for one MB
                                  // CAVLC needs more symbols per MB


#define MAX_PART_NR     3 /*!< Maximum number of different data partitions.
                               Some reasonable number which should reflect
                               what is currently defined in the SE2Partition map (elements.h) */

//Start code and Emulation Prevention need this to be defined in identical manner at encoder and decoder
#define ZEROBYTES_SHORTSTARTCODE 2 //indicates the number of zero bytes in the short start-code prefix

#define Q_BITS          15
#define DQ_BITS         6

#define Q_BITS_8        16
#define DQ_BITS_8       6

// Context Adaptive Lagrange Multiplier (CALM)
#define CALM_MF_FACTOR_THRESHOLD 512.0

#define MAX_PLANE       3
#define IS_FREXT_PROFILE(profile_idc) ( profile_idc>=FREXT_HP || profile_idc == FREXT_CAVLC444 )

#define MAXSLICEGROUPIDS 8


#define NUM_MB_TYPE_CTX  11
#define NUM_B8_TYPE_CTX  9
#define NUM_MV_RES_CTX   10
#define NUM_REF_NO_CTX   6
#define NUM_DELTA_QP_CTX 4
#define NUM_MB_AFF_CTX   4

#define NUM_TRANSFORM_SIZE_CTX 3

#define NUM_IPR_CTX    2
#define NUM_CIPR_CTX   4
#define NUM_CBP_CTX    4
#define NUM_BCBP_CTX   4
#define NUM_MAP_CTX   15
#define NUM_LAST_CTX  15
#define NUM_ONE_CTX    5
#define NUM_ABS_CTX    5

#if IVMP
#define NUM_IVMP_CTX 3
#endif

#if SAIT_PSIP
#define NUM_PSIP_DIR_CTX           1
#define NUM_PSIP_CODE_DIFF_CTX     2
#endif

#if SAIT_DISP
#define NUM_DISP_CTX  3 
#endif

#if (NOKIA_USTC_IVP_VSP_D0126)
#define BUG_FIX_IVP_VSP 1
#endif

#ifndef _MSC_VER
#define UNREFERENCED_PARAMETER(x)
#endif

#if GVD_E0105 // JCT3V-E0105 = HP mode.
#define DEPTH_GRID_CROP 0
#else
#define DEPTH_GRID_CROP 1
#endif
#if (REDUCED_RES)
#define G0239_FLEXRES_SPS_FIX 1
#endif
#define G0239_FLEXRES_WRITE_OUT_PIC_FIX 1

#if (NOKIA_UPMVD_B0147)
#define XH_UP_MVD_BUG_FIX 1
#endif

#if (NOKIA_USTC_3DV)
#define G0239_HLS_FIX 1
#endif

#define MVCD_HLS_FIX 1

#define DGC_PARA_BUG_FIX 1

#endif

